<div class="name-container">
  <span class="name-icon glyphicon glyphicon-tower"></span>
  <span class="org-name title"><%= name %></span>
  <span class="org-id title">(<%= id %>)</span>
</div>
<div class="button-container">
  <button type="button" class="server-detach-org btn btn-danger btn-xs">Detach Organization</button>
</div>
