@white-fg: #fff;
@black-bg: #000;
@dark-fg: #4d535c;
@blue-fg: #428bca;
@green-fg: #47a447;
@green2-fg: #3ba51a;
@red-fg: #d2322d;
@red2-fg: #f00;
@gray-fg: #6f7277;
@gray2-fg: #616161;
@orange-fg: #f90;

@light-dark-fg: #777;
@light-dark-bg: #f5f5f5;
@light-dark-border: #cfcfcf;
@light-dark2-bg: #f9f9f9;
@light-dark2-border: #ccc;

@alert-success-bg: #daeed1;
@alert-success-border: #b2df8d;
@alert-info-bg: #d4eaf5;
@alert-info-border: #9ddbe7;
@alert-warning-bg: #fff8db;
@alert-warning-border: #f1d997;
@alert-danger-bg: #eed6d6;
@alert-danger-border: #e0a2ac;

@icon-blue-bg: #64b3f6;
@icon-blue2-bg: #4e8bbf;
@icon-blue3-bg: #2a6496;
@icon-blue4-bg: #1f83bb;
@icon-gray-bg: #b8b8b8;

@header-fg: #ececec;
@checkmark-fg: #858585;
@scrollbar-bg: #8f8f8f;
@scrollbar-track-bg: #d1d1d1;
