<div class="servers-list-header">
  <h1 class="servers-list-title title">Servers and Attached Organizations</h1>
  <div class="servers-list-buttons">
    <button type="button" class="servers-add-server btn btn-primary">Add Server</button>
    <button type="button" class="servers-attach-org btn btn-primary">Attach Organization</button>
  </div>
</div>
<div class="alerts-container"></div>
<div class="servers-list-container">
  <div class="no-servers">
    There are no servers on this host.
  </div>
</div>
