<div class="form-group">
  <label>Name</label>
  <input type="text" class="form-control" placeholder="Enter name" data-toggle="tooltip" title="Name of user">
</div>
<div class="form-group">
  <label>Select an organization</label>
  <select class="form-control">
    <% _.each(orgs, function(org) { %>
      <option value="<%= org.id %>"><%= org.name %></option>
    <% }); %>
  </select>
</div>
