<div class="navbar navbar-inverse" role="navigation">
  <div class="container">
    <div class="navbar-header">
      <a class="navbar-brand" href="#">pritunl</a>
    </div>
    <ul class="nav navbar-nav">
      <li class="dashboard"><a href="#/dashboard">Dashboard</a></li>
      <li class="users"><a href="#/users">Users</a></li>
      <li class="servers"><a href="#/servers">Servers</a></li>
    </ul>
    <ul class="nav navbar-nav navbar-right">
      <li class="change-password"><a>Change Password</a></li>
      <li class="logout"><a href="#/logout">Logout</a></li>
    </ul>
  </div>
</div>
