.title {
  font-weight: bold;
  font-family: 'Ubuntu', sans-serif;
}

.title a,
.title a:hover {
  color: @dark-fg;
}

.container {
  width: 940px;
}

.alert {
  padding: 10px;
  margin-bottom: 10px;
  .transition(background-color, 175ms);
}

.alert.flash {
  background-color: @white-fg;
}

.alert .span {
  vertical-align: text-top;
}

.alert-dismissable .close {
  top: 4px;
  right: 4px;
  opacity: 0.5;
  height: 10px;
  line-height: 10px;
  vertical-align: text-top;
}

.alert-success {
  background-color: @alert-success-bg;
  border-color: @alert-success-border;
}

.alert-info {
  background-color: @alert-info-bg;
  border-color: @alert-info-border;
}

.alert-warning {
  background-color: @alert-warning-bg;
  border-color: @alert-warning-border;
}

.alert-danger {
  background-color: @alert-danger-bg;
  border-color: @alert-danger-border;
}

.modal {
  overflow-y: auto;
}

.modal .modal-body {
  padding: 20px 20px 0 20px;
}

.modal .modal-body .split {
  .clearfix();
}

.modal .modal-body .split .left,
.modal .modal-body .split .right {
  margin-right: 20px;
  width: 238px;
}

.modal .modal-body .split .left {
  float: left;
}

.modal .modal-body .split .right {
  float: right;
}

.modal .modal-body .qrcode {
  width: 192px;
  height: 192px;
  margin: 15px auto 0 auto;
}

.modal .modal-dialog {
  width: 600px;
  position: fixed;
  top: 0;
  .left-calc(~'50% - 300px');
}

.modal .modal-dialog .modal-footer {
  background-color: @light-dark-bg;
  .border-bottom-left-radius(6px);
  .border-bottom-right-radius(6px);
}

.modal label {
  font-weight: normal;
}

.modal .form-group {
  margin: 0 0 20px 0;
}

.modal .form-control {
  width: 200px;
}

.modal .modal-user-list li {
  color: @light-dark-fg;
}

.modal .key-link input {
  width: 480px;
}

.modal .otp-auth-key {
  text-align: center;
}

.modal .otp-auth-key input {
  margin: 0 auto;
}

.modal .generate-new-key {
  margin-top: 15px;
  width: 192px;
}

.navbar .navbar-brand,
.navbar .navbar-brand:hover,
.navbar .navbar-brand:active,
.login .login-header {
  font-family: 'Fredoka One', cursive;
  padding: 13px 15px 0 15px;
  font-size: 28px;
  cursor: default;
  color: @header-fg;
}

.navbar .change-password {
  cursor: pointer;
}

.selector {
  width: 19px;
  height: 19px;
  margin-right: 10px;
  padding-left: 1px;
  border: 1px solid @light-dark-border;
  float: left;
  .border-radius(3px);
}

.selector .selector-inner {
  font-size: 14px;
  top: auto;
  color: @checkmark-fg;
  display: none;
}

.selector.selected .selector-inner {
  display: inline;
}

.selector:active {
  .box-shadow(0 1px 2px rgba(0, 0, 0, 0.05),
    0 1px 3px rgba(0, 0, 0, 0.1) inset);
  .background-clip-padding;
}




header.blur {
  .blur(5px);
}

#app.blur {
  .blur(10px);
}

.navbar {
  height: 50px;
  overflow-x: hidden;
  overflow-y: hidden;
  border-radius: 0;
}

.navbar-collapse {
  padding-right: 0;
}




.login,
.login-backdrop {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 2050;
}

.login-backdrop {
  background-color: @black-bg;
  opacity: 0.75;
  z-index: 2000;
  cursor: default;
}

.login .login-box {
  position: fixed;
  width: 374px;
  margin: 0 auto;
  opacity: 1;
  .top-calc(~'50% - 164px');
  .left-calc(~'50% - 187px');
}

.login .login-form {
  background-color: @light-dark2-bg;
  padding: 40px 35px;
  border-bottom-left-radius: 6px;
  border-bottom-right-radius: 6px;
}

.login .login-header {
  margin: 0;
  padding: 10px 15px 10px 15px;
  border-top-left-radius: 6px;
  border-top-right-radius: 6px;
}

.login .form-control {
  position: relative;
  font-size: 16px;
  height: auto;
  padding: 10px;
}

.login .form-control:focus {
  z-index: 2;
}

.login .form-control[type="text"] {
  margin-bottom: -1px;
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
}

.login .form-control[type="password"] {
  margin-bottom: 10px;
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}

.login .login-button {
  margin-top: 13px;
}




.orgs-list .orgs-list-title,
.servers-list .servers-list-title {
  color: @dark-fg;
  display: inline-block;
  margin-top: 6px;
  margin-bottom: 19px;
  font-size: 22px;
}

.orgs-list .orgs-list-buttons,
.servers-list .servers-list-buttons {
  float: right;
  display: block;
}




.users-list,
.servers-list .server,
.orgs-list-container .no-orgs,
.servers-list .no-servers {
  margin-bottom: 25px;
  border: 1px solid @light-dark-border;
  background-color: @light-dark2-bg;
  .border-radius(4px);
  .box-shadow(0 2px 1px rgba(0, 0, 0, 0.05),
    0 -1px 2px rgba(0, 0, 0, 0.05) inset);
  .background-clip-padding;
}

.users-list .label,
.servers-list .server .label {
  cursor: default;
  margin-top: 1px;
  margin-right: 14px;
  padding: 6px 12px;
}

.users-list .users-list-title,
.servers-list .server .server-title {
  margin: 0;
  display: inline-block;
  line-height: 16px;
  position: relative;
  top: 2px;
}

.users-list .users-list-title a,
.servers-list .server .server-title a {
  font-size: 19px;
}

.users-list .users-list-header,
.servers-list .server .server-header {
  border-top-left-radius: 4px;
  border-top-right-radius: 4px;
  background-color: @white-fg;
  padding: 10px 11px 16px 14px;
  border-bottom: 1px solid @light-dark2-border;
}

.users-list .users-list-header button,
.servers-list .server .server-header button {
  margin-left: 10px;
  float: right;
}

.users-list-container,
.server-orgs-list {
  padding: 0 13px 13px 13px;
}

.orgs-list-container .no-orgs,
.servers-list .no-servers {
  text-align: center;
  font-size: 14px;
  padding: 10px;
  color: @light-dark-fg;
  background-color: @light-dark-bg;
  display: none;
}

.servers-list .server .no-org-warning {
  float: right;
  padding: 10px 12px 10px 12px;
  margin-top: 0;
  margin-right: 0;
  height: 30px;
  display: none;
}




.users-list .user,
.users-list .no-users,
.server-orgs-list .org,
.server-orgs-list .no-orgs {
  height: 40px;
  background: @white-fg;
  border: 1px solid @light-dark-border;
  margin-top: 12px;
  .border-radius(3px);
  .box-shadow(0 1px 0 rgba(255, 255, 255, 0.02)
    0 1px 3px rgba(0, 0, 0, 0.08) inset);
  .background-clip-padding;
}

.users-list .no-users,
.server-orgs-list .no-orgs {
  text-align: center;
  font-size: 14px;
  color: @light-dark-fg;
  background-color: @light-dark-bg;
  padding-top: 10px;
  display: none;
}

.users-list .org-title,
.servers-list .server .server-title a {
  cursor: pointer;
}

.users-list .user .selector {
  margin: 10px 10px;
}




.users-list .user .name-container,
.server-orgs-list .org .name-container {
  float: left;
  height: 28px;
  padding-top: 0;
  padding-left: 13px;
  margin-top: 3px;
  border-left: 1px solid @light-dark-border;
}

.users-list .user .name-container {
  margin-top: 5px;
}

.server-orgs-list .org .name-container {
  border-left: 0 none;
}

.users-list .user .name-container .name-icon,
.server-orgs-list .org .name-container .name-icon {
  top: 2px;
  margin-top: 0;
  margin-right: 6px;
  font-size: 19px;
  color: @icon-blue-bg;
  vertical-align: text-top;
}

.users-list .user .name-container.type-server .name-icon,
.users-list .user .name-container.type-server .user-name {
  color: @icon-gray-bg;
}

.users-list .user .name-container .name-icon {
  top: 1px;
}

.users-list .user .name-container .user-name {
  position: relative;
  top: -2px;
}

.users-list .user .name-container .user-name,
.server-orgs-list .org .org-name {
  font-size: 18px;
  cursor: pointer;
  vertical-align: text-top;
}

.users-list .users-list-title .org-id,
.users-list .user .name-container .user-id,
.servers-list .server .server-title .server-id,
.servers-list .server .org .org-id {
  position: relative;
  color: @dark-fg;
  font-size: 10px;
  display: none;
}

.servers-list .server .org .org-id {
  top: 4px;
}

.users-list .user .name-container .user-id {
  top: 2px;
}

.users-list .users-list-title .org-id,
.servers-list .server .server-title .server-id {
  top: -2px;
}

.users-list.show-hidden .users-list-title .org-id,
.users-list.show-hidden .user .name-container .user-id,
.servers-list .server.show-hidden .server-title .server-id,
.servers-list .server.show-hidden .org .org-id {
  display: inline;
}

.server-orgs-list .org .org-name {
  color: @blue-fg;
  cursor: default;
}

.users-list .user .download-key,
.users-list .user .get-key-link,
.users-list .user .get-otp-auth {
  float: right;
  top: -1px;
  font-size: 20px;
  color: @icon-blue2-bg;
  cursor: pointer;
}

.users-list .user .get-key-link,
.users-list .user .get-otp-auth {
  margin-right: 5px;
}

.users-list .user .get-otp-auth.no-otp-auth {
  display: none;
}

.users-list .user .right-container .download-key:hover,
.users-list .user .right-container .get-key-link:hover,
.users-list .user .right-container .get-otp-auth:hover {
  text-decoration: none;
  color: @icon-blue3-bg;
}

.users-list .user .right-container,
.server-orgs-list .org .button-container {
  float: right;
  display: inline-block;
  margin-top: 5px;
  height: 28px;
  width: 170px;
  padding: 3px 8px 0 12px;
  border-left: 1px solid @light-dark-border;
}

.users-list .user .right-container.no-otp-auth {
  width: 145px;
}

.server-orgs-list .org .button-container {
  width: auto;
  border-left: 0 none;
}

.users-list .user .status-container {
  display: inline-block;
  cursor: default;
}

.users-list .user .status-container .status-icon {
  display: inline-block;
  position: relative;
  top: 3px;
  margin-right: 4px;
  width: 16px;
  height: 16px;
  .border-radius(50%);
}

.users-list .user .tooltip-inner {
    white-space: pre-wrap;
}


.users-list .user .status-container .status-icon.online {
  background-color: @green-fg;
}

.users-list .user .status-container .status-icon.offline {
  background-color: @red-fg;
}

.users-list .user .status-container .status-text {
  color: @gray-fg;
}




.dashboard .status-container,
.dashboard .log-container {
  margin-bottom: 25px;
  border: 1px solid @light-dark-border;
  background-color: @light-dark2-bg;
  .border-radius(4px);
  .box-shadow(0 2px 1px rgba(0, 0, 0, 0.05),
    0 -1px 2px rgba(0, 0, 0, 0.05) inset);
  .background-clip-padding;
}

.dashboard .status-container {
  margin-bottom: 15px;
}

.servers-list .server .server-info {
  background-color: @white-fg;
}

.dashboard .status-container table {
  width: 100%;
  table-layout: fixed;
}

.servers-list .server .server-info .status-items {
  margin-right: 11px;
  width: 300px;
  float: left;
}

.servers-list .server .server-info .server-output {
  border-bottom: 1px solid @light-dark-border;
}

.servers-list .server .server-info .server-output .server-output-title {
  color: @dark-fg;
  font-size: 16px;
  margin: 0;
  padding-top: 5px;
  height: 24px;
}

.servers-list .server .server-info .server-output .server-output-title span {
  vertical-align: text-top;
}

.servers-list .server .server-info .server-output .server-output-icon {
  color: @icon-blue4-bg;
  top: -1px;
  font-size: 18px;
}

.servers-list .server .server-info .server-output .server-output-clear {
  float: right;
  color: @dark-fg;
  top: 3px;
  font-size: 12px;
  margin-right: 12px;
}

.servers-list .server .server-info .server-output .server-output-clear:hover {
  color: @black-bg;
}

.servers-list .server .server-info .server-output .server-output-viewer {
  padding: 5px 10px 10px 0;
}

.servers-list .server .server-info .server-output .text-viewer {
  height: 262px;
  border: 1px solid @light-dark-border;
}

.dashboard .status-container .status-item,
.servers-list .server .server-info .status-item {
  padding: 20px 0;
  border-right: 1px solid @light-dark-border;
  text-align: center;
}

.servers-list .server .server-info .status-item {
  height: 43px;
  padding: 9px 15px;
  text-align: left;
  border-bottom: 1px solid @light-dark-border;
}

.servers-list .server .server-info .status-item.last {
 border-bottom: 0 none;
}

.dashboard .status-container .status-item.last {
  border-right: 0 none;
}

.dashboard .status-container .status-item span {
  vertical-align: top;
}

.dashboard .status-container .status-item .status-title,
.servers-list .server .server-info .status-item .status-title {
  color: @dark-fg;
  font-size: 26px;
  margin: 0 0 3px 0;
}

.servers-list .server .server-info .status-item .status-title {
  font-size: 20px;
  height: 22px;
  margin: 0;
}

.servers-list .server .server-info .status-item .status-title span {
  vertical-align: text-top;
}

.dashboard .status-container .status-item .status-icon,
.servers-list .server .server-info .status-item .status-icon {
  color: @icon-blue4-bg;
  font-size: 26px;
}

.servers-list .server .server-info .status-item .status-icon {
  font-size: 18px;
  margin-right: 0;
}

.dashboard .status-container .status-item .status-icon {
  top: -2px;
}

.dashboard .status-container .status-item .status-icon.glyphicon-cloud {
  top: 0;
}

.servers-list .server .server-info .server-port .status-icon {
  top: 0;
}

.servers-list .server .server-info .status-item .status-text {
  color: @dark-fg;
  float: right;
  position: relative;
  top: -21px;
}

.dashboard .status-container .status-text {
  font-size: 16px;
  font-weight: normal;
}

.dashboard .status-container .status-text .status-num {
  font-weight: bold;
  position: relative;
  top: 1px;
}

.dashboard .status-container .status-text .status-num.none {
  color: @gray2-fg;
}

.dashboard .status-container .status-text .status-num.error {
  color: @red2-fg;
}

.dashboard .status-container .status-text .status-num.warning {
  color: @orange-fg;
}

.dashboard .status-container .status-text .status-num.success {
  color: @green2-fg;
}

.dashboard .status-container .server-version {
  position: absolute;
  top: -1px;
  right: 2px;
  font-size: 12px;
  z-index: 5000;
}

.dashboard .log-container {
  padding: 20px 20px 5px 20px;
}

.dashboard .log-container .log-title {
  color: @dark-fg;
  margin: 0;
  font-size: 20px;
  padding-bottom: 17px;
  border-bottom: 1px solid @light-dark-border;
}

.dashboard .log-container .log-entry {
  color: @dark-fg;
  padding: 15px 15px 15px 10px;
  border-bottom: 1px solid @light-dark-border;
}

.dashboard .log-container .log-entry.last {
  border-bottom: 0 none;
}

.dashboard .log-container .log-entry span {
  vertical-align: top;
}

.dashboard .log-container .log-entry .log-icon {
  color: @icon-blue4-bg;
  font-size: 15px;
  margin-right: 7px;
  float: left;
}

.dashboard .log-container .log-entry .log-msg {
  float: left;
}

.dashboard .log-container .log-entry .log-time {
  color: @light-dark-fg;
  float: right;
}




.server-settings-modal .modal .modal-dialog {
  .top-calc(~'50% - 340px');
}

.server-settings-modal .local-network {
  margin-top: -13px;
}

.delete-users-modal .modal .modal-dialog {
  .top-calc(~'50% - 195px');
}

.key-link-modal .modal .modal-dialog {
  .top-calc(~'50% - 198px');
}

.detach-org-modal .modal .modal-dialog {
  .top-calc(~'50% - 183px');
}

.add-org-modal .modal .modal-dialog,
.rename-org-modal .modal .modal-dialog,
.rename-user-modal .modal .modal-dialog {
  .top-calc(~'50% - 200px');
}

.delete-org-modal .modal .modal-dialog,
.delete-server-modal .modal .modal-dialog {
  .top-calc(~'50% - 225px');
}

.add-user-modal .modal .modal-dialog,
.attach-org-modal .modal .modal-dialog,
.change-password-modal .modal .modal-dialog {
  .top-calc(~'50% - 240px');
}

.otp-auth-modal .modal .modal-dialog {
  .top-calc(~'50% - 325px');
}
