.border-radius(@radius) {
  -webkit-border-radius: @radius;
  -moz-border-radius: @radius;
  border-radius: @radius;
}

.border-bottom-left-radius(@radius) {
  -webkit-border-bottom-left-radius: @radius;
  -moz-border-bottom-left-radius: @radius;
  border-bottom-left-radius: @radius;
}

.border-bottom-right-radius(@radius) {
  -webkit-border-bottom-right-radius: @radius;
  -moz-border-bottom-right-radius: @radius;
  border-bottom-right-radius: @radius;
}

.box-shadow(...) {
  @args: ~`"@{arguments}".replace(/[\[\]]/g, '')`;
  -webkit-box-shadow: @args;
  -moz-box-shadow: @args;
  -o-box-shadow: @args;
  box-shadow: @args;
}

.left-calc(@func) {
  left: -webkit-calc(@func);
  left: -moz-calc(@func);
  left: -o-calc(@func);
  left: calc(@func);
}

.top-calc(@func) {
  top: -webkit-calc(@func);
  top: -moz-calc(@func);
  top: -o-calc(@func);
  top: calc(@func);
}

.transition(@property, @duration) {
  -webkit-transition: @property @duration;
  -moz-transition: @property @duration;
  -o-transition: @property @duration;
  transition: @property @duration;
}

.blur(@value) {
  -webkit-filter: blur(@value);
  -moz-filter: blur(@value);
  -ms-filter: blur(@value);
  -o-filter: blur(@value);
  filter: blur(@value);
}

.background-clip-padding {
  -webkit-background-clip: padding;
  -moz-background-clip: padding;
  background-clip: padding-box;
}
