<div class="orgs-list">
  <div class="orgs-list-header">
    <h1 class="orgs-list-title title">Users and Organizations</h1>
    <div class="orgs-list-buttons">
      <button type="button" class="orgs-add-org btn btn-primary">Add Organization</button>
      <button type="button" class="orgs-add-user btn btn-primary">Add User</button>
      <button type="button" class="orgs-del-selected btn btn-danger" disabled>Delete Selected Users</button>
    </div>
  </div>
  <div class="alerts-container"></div>
  <div class="orgs-list-container">
    <div class="no-orgs">
      There are no organizations on this host.
    </div>
  </div>
</div>
