<div class="login-box">
  <h2 class="login-header navbar-inverse">pritunl</h2>
  <div class="login-form">
    <input type="text" name="username" class="username form-control" placeholder="Username" autofocus>
    <input type="password" name="password" class="password form-control" placeholder="Password">
    <button class="login-button btn btn-lg btn-primary btn-block">Sign in</button>
  </div>
</div>
