<div class="server-header">
  <div class="label label-primary toggle-hidden no-select">Server</div>
  <h2 class="server-title title">
    <a class="no-select" data-toggle="tooltip" title="Click to open server settings"></a>
    <span class="server-id title">(<%= id %>)</span>
  </h2>
  <button type="button" class="server-del btn btn-danger btn-sm">Delete Server</button>
  <button type="button" class="server-stop btn btn-warning btn-sm">Stop Server</button>
  <button type="button" class="server-start btn btn-success btn-sm">Start Server</button>
  <button type="button" class="server-restart btn btn-primary btn-sm">Restart Server</button>
  <span class="no-org-warning label label-default">
    Server must have an organization attached before starting
  </span>
</div>
<div class="server-info">
  <div class="status-items">
    <div class="status-item server-status">
      <h3 class="status-title title">
        <span class="status-icon glyphicon glyphicon-dashboard"></span>
        <span>Status</span>
      </h3>
      <div class="status-text title"></div>
    </div>
    <div class="status-item server-uptime">
      <h3 class="status-title title">
        <span class="status-icon glyphicon glyphicon-time"></span>
        <span>Uptime</span>
      </h3>
      <div class="status-text title"></div>
    </div>
    <div class="status-item server-users">
      <h3 class="status-title title">
        <span class="status-icon glyphicon glyphicon-user"></span>
        <span>Users</span>
      </h3>
      <div class="status-text title">
        <span class="status-num"></span> users online
      </div>
    </div>
    <div class="status-item server-network">
      <h3 class="status-title title">
        <span class="status-icon glyphicon glyphicon-signal"></span>
        <span>Network</span>
      </h3>
      <div class="status-text title"></div>
    </div>
    <div class="status-item server-interface">
      <h3 class="status-title title">
        <span class="status-icon glyphicon glyphicon-transfer"></span>
        <span>Interface</span>
      </h3>
      <div class="status-text title"></div>
    </div>
    <div class="status-item server-port">
      <h3 class="status-title title">
        <span class="status-icon glyphicon glyphicon-cloud-upload"></span>
        <span>Port</span>
      </h3>
      <div class="status-text title"></div>
    </div>
    <div class="status-item server-public-address last">
      <h3 class="status-title title">
        <span class="status-icon glyphicon glyphicon-globe"></span>
        <span>Public IP</span>
      </h3>
      <div class="status-text title"></div>
    </div>
  </div>
  <div class="server-output">
    <h3 class="server-output-title title">
      <span class="server-output-icon glyphicon glyphicon-record"></span>
      <span>Server Output</span>
      <span class="server-output-clear glyphicon glyphicon-trash" data-toggle="tooltip" title="Click to clear server output"></span>
    </h3>
    <div class="server-output-viewer"></div>
  </div>
</div>
