<div class="otp-auth-key form-group">
  <label>Two-step authentication key</label>
  <input type="text" class="form-control" readonly>
  <div class="qrcode"></div>
  <button type="button" class="generate-new-key btn btn-danger">Generate New Key</button>
</div>
