<table>
  <tbody>
    <tr>
      <td class="status-item orgs-status">
        <h3 class="status-title title">
          <span class="status-icon glyphicon glyphicon-tower"></span>
          <span>Organizations</span>
        </h3>
        <div class="status-text title">
          <span class="status-num">-/-</span>
          <span>organizations available</span>
        </div>
      </td>
      <td class="status-item users-status">
        <h3 class="status-title title">
          <span class="status-icon glyphicon glyphicon-user"></span>
          <span>Users</span>
        </h3>
        <div class="status-text title">
          <span class="status-num">-/-</span>
          <span>users online</span>
        </div>
      </td>
      <td class="status-item last servers-status">
        <h3 class="status-title title">
          <span class="status-icon glyphicon glyphicon-cloud"></span>
          <span>Servers</span>
        </h3>
        <div class="status-text title">
          <span class="status-num">-/-</span>
          <span>servers online</span>
        </div>
        <div class="server-version"></div>
      </td>
    </tr>
  </tbody>
</table>
