<div class="form-group">
  <label>Enter the name of the server to confirm</label>
  <input type="text" class="form-control" placeholder="Enter name" data-toggle="tooltip" title="Name of server">
</div>
