*, *:before, *:after {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}

body {
  background-color: #efefef;
  overflow-y: scroll;
}

a,
a:focus,
a:hover,
a:active {
  outline: 0;
}

ul {
  padding-left: 30px;
}

::-webkit-scrollbar {
  height: 8px;
  width: 8px;
}

::-webkit-scrollbar-thumb {
  background-color: @scrollbar-bg;
}

::-webkit-scrollbar-track {
  background-color: @scrollbar-track-bg;
}

@font-face {
  font-family: 'Fredoka One';
  font-style: normal;
  font-weight: 400;
  src: url('../fonts/fredoka-one.eot') format('embedded-opentype'),
    url('../fonts/fredoka-one.woff') format('woff');
}

@font-face {
  font-family: 'Ubuntu';
  font-style: normal;
  font-weight: 400;
  src: url('../fonts/ubuntu.eot') format('embedded-opentype'),
    url('../fonts/ubuntu.woff') format('woff');
}

@font-face {
  font-family: 'Ubuntu';
  font-style: normal;
  font-weight: 700;
  src: url('../fonts/ubuntu-bold.eot') format('embedded-opentype'),
    url('../fonts/ubuntu-bold.woff') format('woff');
}
