<div class="form-group">
  <label>Enter new password</label>
  <input type="password" class="pass form-control" placeholder="Enter password">
</div>
<div class="form-group">
  <label>Verify password</label>
  <input type="password" class="verify-pass form-control" placeholder="Verify password">
</div>
